ScreenTimeAggregate class

This data class holds information about total and social screen time.

@property totalScreenTime total screen time in milliseconds. @property socialScreenTime social screen time in milliseconds.

Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

ScreenTimeAggregate({required double totalScreenTime, required double socialScreenTime})
Constructor
ScreenTimeAggregate.empty()
Create an empty ScreenTimeAggregate
factory
ScreenTimeAggregate.fromJson(Map<String, dynamic> json)
Create a ScreenTimeAggregate from a json
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNaN bool

Available on ScreenTimeAggregate, provided by the ScreenTimeAggregateExtension extension

check if the screen time aggregate is nan
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socialScreenTime double
social screen time in milliseconds.
final
totalScreenTime double
total screen time in milliseconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert the ScreenTimeAggregate to a json
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited